@@ -16,6 +16,8 @@ class Response:
             'msg': self.msg
         }
 
+    def data_size(self):
+        return len(self.data)
 
 class BillType(Enum):
     # 划转
